# **tygle**

**Ty**ped Goo**gle** or simply *~~tiger~~* tygle.  
Created using [Aiogoogle](https://github.com/omarryhan/aiogoogle) for interaction with Google APIs and [pydantic](https://github.com/samuelcolvin/pydantic) for typing.

## Work In Progress
🛑 This is a WIP package. Expect bugs and changes.

## Installation
In order to install the package, install tygle itself and APIs you need.  
For example:  
`pip install tygle[tygle-sheets]`

## Supported APIs
Currently, tygle only supports following APIs:  
1. Sheets
2. Drive